ImageCompressPlusHostApi class

Run with: flutter pub run pigeon
--input pigeons/messages.dart

Constructors

ImageCompressPlusHostApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for ImageCompressPlusHostApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compressWithFile({required String path, int targetWidth = 1920, int targetHeight = 1080, int quality = 95, int rotate = 0, bool autoCorrectionAngle = true, HostFormat targetFormat = HostFormat.jpeg, bool keepExif = false, int numberOfRetries = 5}) Future<Uint8List?>
compressWithFileAndGetFile({required String path, int targetWidth = 1920, int targetHeight = 1080, int quality = 95, required String targetPath, int rotate = 0, bool autoCorrectionAngle = true, HostFormat targetFormat = HostFormat.jpeg, bool keepExif = false, int numberOfRetries = 5}) Future<String?>
compressWithList({required Uint8List image, int targetWidth = 1920, int targetHeight = 1080, int quality = 95, int rotate = 0, bool autoCorrectionAngle = true, HostFormat targetFormat = HostFormat.jpeg, bool keepExif = false}) Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showLog(bool value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>